import { AwsSdkSigV4AuthInputConfig, AwsSdkSigV4AuthResolvedConfig, AwsSdkSigV4PreviouslyResolved } from "@aws-sdk/core";
import { HandlerExecutionContext, HttpAuthScheme, HttpAuthSchemeParameters, HttpAuthSchemeParametersProvider, HttpAuthSchemeProvider } from "@smithy/types";
import { SageMakerGeospatialClientResolvedConfig } from "../SageMakerGeospatialClient";
/**
 * @internal
 */
export interface SageMakerGeospatialHttpAuthSchemeParameters extends HttpAuthSchemeParameters {
    region?: string;
}
/**
 * @internal
 */
export interface SageMakerGeospatialHttpAuthSchemeParametersProvider extends HttpAuthSchemeParametersProvider<SageMakerGeospatialClientResolvedConfig, HandlerExecutionContext, SageMakerGeospatialHttpAuthSchemeParameters, object> {
}
/**
 * @internal
 */
export declare const defaultSageMakerGeospatialHttpAuthSchemeParametersProvider: (config: SageMakerGeospatialClientResolvedConfig, context: HandlerExecutionContext, input: object) => Promise<SageMakerGeospatialHttpAuthSchemeParameters>;
/**
 * @internal
 */
export interface SageMakerGeospatialHttpAuthSchemeProvider extends HttpAuthSchemeProvider<SageMakerGeospatialHttpAuthSchemeParameters> {
}
/**
 * @internal
 */
export declare const defaultSageMakerGeospatialHttpAuthSchemeProvider: SageMakerGeospatialHttpAuthSchemeProvider;
/**
 * @internal
 */
export interface HttpAuthSchemeInputConfig extends AwsSdkSigV4AuthInputConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    httpAuthSchemes?: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    httpAuthSchemeProvider?: SageMakerGeospatialHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export interface HttpAuthSchemeResolvedConfig extends AwsSdkSigV4AuthResolvedConfig {
    /**
     * experimentalIdentityAndAuth: Configuration of HttpAuthSchemes for a client which provides default identity providers and signers per auth scheme.
     * @internal
     */
    readonly httpAuthSchemes: HttpAuthScheme[];
    /**
     * experimentalIdentityAndAuth: Configuration of an HttpAuthSchemeProvider for a client which resolves which HttpAuthScheme to use.
     * @internal
     */
    readonly httpAuthSchemeProvider: SageMakerGeospatialHttpAuthSchemeProvider;
}
/**
 * @internal
 */
export declare const resolveHttpAuthSchemeConfig: <T>(config: T & HttpAuthSchemeInputConfig & AwsSdkSigV4PreviouslyResolved) => T & HttpAuthSchemeResolvedConfig;
